@@ -397,12 +397,8 @@ menu_position_under_tree_view (GtkMenu     *menu,
       if (gtk_widget_get_direction (GTK_WIDGET (tree_view)) == GTK_TEXT_DIR_RTL)
         {
           GtkRequisition requisition;
-#if !GTK_CHECK_VERSION(2,90,7)
-          gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
-#else
           gtk_widget_get_preferred_size (GTK_WIDGET (menu), &requisition,
                                          NULL);
-#endif
           *x += rect.width - requisition.width;
         }
     }
@@ -419,12 +415,8 @@ menu_position_under_tree_view (GtkMenu     *menu,
         {
           GtkRequisition requisition;
 
-#if !GTK_CHECK_VERSION(2,90,7)
-          gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
-#else
           gtk_widget_get_preferred_size (GTK_WIDGET (menu), &requisition,
                                          NULL);
-#endif
 
           *x += allocation.width - requisition.width;
         }
@@ -796,6 +788,9 @@ peas_gtk_plugin_manager_view_class_init (PeasGtkPluginManagerViewClass *klass)
                                                          "show-builtin",
                                                          "If builtin plugins should be shown",
                                                          FALSE,
+#if GLIB_CHECK_VERSION (2, 26, 0)
+                                                         G_PARAM_DEPRECATED |
+#endif
                                                          G_PARAM_READWRITE |
                                                          G_PARAM_STATIC_STRINGS));
 
@@ -848,6 +843,8 @@ peas_gtk_plugin_manager_view_new (PeasEngine *engine)
  * @show_builtin: If builtin plugins should be shown.
  *
  * Sets if builtin plugins should be shown.
+ *
+ * Deprecated: 1.2. Use hidden plugins instead.
  */
 void
 peas_gtk_plugin_manager_view_set_show_builtin (PeasGtkPluginManagerView *view,
@@ -908,6 +905,8 @@ peas_gtk_plugin_manager_view_set_show_builtin (PeasGtkPluginManagerView *view,
  * Returns if builtin plugins should be shown.
  *
  * Returns: if builtin plugins should be shown.
+ *
+ * Deprecated: 1.2. Use hidden plugins instead.
  */
 gboolean
 peas_gtk_plugin_manager_view_get_show_builtin (PeasGtkPluginManagerView *view)
